@@ -32,7 +32,7 @@ impl ::core::default::Default for OPERATION_END_PARAMETERS {
 }
 #[doc = "*Required features: `\"Win32_Storage_OperationRecorder\"`*"]
 #[repr(transparent)]
-#[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
+#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
 pub struct OPERATION_END_PARAMETERS_FLAGS(pub u32);
 #[doc = "*Required features: `\"Win32_Storage_OperationRecorder\"`*"]
 pub const OPERATION_END_DISCARD: OPERATION_END_PARAMETERS_FLAGS = OPERATION_END_PARAMETERS_FLAGS(1u32);
@@ -85,7 +85,7 @@ impl ::core::ops::Not for OPERATION_END_PARAMETERS_FLAGS {
 }
 #[doc = "*Required features: `\"Win32_Storage_OperationRecorder\"`*"]
 #[repr(transparent)]
-#[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
+#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
 pub struct OPERATION_START_FLAGS(pub u32);
 #[doc = "*Required features: `\"Win32_Storage_OperationRecorder\"`*"]
 pub const OPERATION_START_TRACE_CURRENT_THREAD: OPERATION_START_FLAGS = OPERATION_START_FLAGS(1u32);
@@ -172,31 +172,21 @@ impl ::core::default::Default for OPERATION_START_PARAMETERS {
 #[cfg(feature = "Win32_Foundation")]
 #[inline]
 pub unsafe fn OperationEnd(operationendparams: *const OPERATION_END_PARAMETERS) -> super::super::Foundation::BOOL {
-    #[cfg(windows)]
-    {
-        #[link(name = "windows")]
-        extern "system" {
-            fn OperationEnd(operationendparams: *const OPERATION_END_PARAMETERS) -> super::super::Foundation::BOOL;
-        }
-        ::core::mem::transmute(OperationEnd(::core::mem::transmute(operationendparams)))
+    #[cfg_attr(windows, link(name = "windows"))]
+    extern "system" {
+        fn OperationEnd(operationendparams: *const OPERATION_END_PARAMETERS) -> super::super::Foundation::BOOL;
     }
-    #[cfg(not(windows))]
-    unimplemented!("Unsupported target OS");
+    OperationEnd(::core::mem::transmute(operationendparams))
 }
 #[doc = "*Required features: `\"Win32_Storage_OperationRecorder\"`, `\"Win32_Foundation\"`*"]
 #[cfg(feature = "Win32_Foundation")]
 #[inline]
 pub unsafe fn OperationStart(operationstartparams: *const OPERATION_START_PARAMETERS) -> super::super::Foundation::BOOL {
-    #[cfg(windows)]
-    {
-        #[link(name = "windows")]
-        extern "system" {
-            fn OperationStart(operationstartparams: *const OPERATION_START_PARAMETERS) -> super::super::Foundation::BOOL;
-        }
-        ::core::mem::transmute(OperationStart(::core::mem::transmute(operationstartparams)))
+    #[cfg_attr(windows, link(name = "windows"))]
+    extern "system" {
+        fn OperationStart(operationstartparams: *const OPERATION_START_PARAMETERS) -> super::super::Foundation::BOOL;
     }
-    #[cfg(not(windows))]
-    unimplemented!("Unsupported target OS");
+    OperationStart(::core::mem::transmute(operationstartparams))
 }
 #[cfg(feature = "implement")]
 ::core::include!("impl.rs");
