@@ -1,6 +1,6 @@
 #[doc = "*Required features: `\"Win32_System_Kernel\"`*"]
 #[repr(transparent)]
-#[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
+#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
 pub struct COMPARTMENT_ID(pub i32);
 #[doc = "*Required features: `\"Win32_System_Kernel\"`*"]
 pub const UNSPECIFIED_COMPARTMENT_ID: COMPARTMENT_ID = COMPARTMENT_ID(0i32);
@@ -59,7 +59,7 @@ impl ::core::default::Default for CSTRING {
 }
 #[doc = "*Required features: `\"Win32_System_Kernel\"`*"]
 #[repr(transparent)]
-#[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
+#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
 pub struct EVENT_TYPE(pub i32);
 #[doc = "*Required features: `\"Win32_System_Kernel\"`*"]
 pub const NotificationEvent: EVENT_TYPE = EVENT_TYPE(0i32);
@@ -86,7 +86,7 @@ impl ::core::fmt::Debug for EVENT_TYPE {
 }
 #[doc = "*Required features: `\"Win32_System_Kernel\"`*"]
 #[repr(transparent)]
-#[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
+#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
 pub struct EXCEPTION_DISPOSITION(pub i32);
 #[doc = "*Required features: `\"Win32_System_Kernel\"`*"]
 pub const ExceptionContinueExecution: EXCEPTION_DISPOSITION = EXCEPTION_DISPOSITION(0i32);
@@ -350,7 +350,7 @@ pub const MAXULONG: u32 = 4294967295u32;
 pub const MAXUSHORT: u32 = 65535u32;
 #[doc = "*Required features: `\"Win32_System_Kernel\"`*"]
 #[repr(transparent)]
-#[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
+#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
 pub struct NT_PRODUCT_TYPE(pub i32);
 #[doc = "*Required features: `\"Win32_System_Kernel\"`*"]
 pub const NtProductWinNt: NT_PRODUCT_TYPE = NT_PRODUCT_TYPE(1i32);
@@ -772,100 +772,65 @@ pub const RTL_BALANCED_NODE_RESERVED_PARENT_MASK: u32 = 3u32;
 #[doc = "*Required features: `\"Win32_System_Kernel\"`*"]
 #[inline]
 pub unsafe fn RtlFirstEntrySList(listhead: *const SLIST_HEADER) -> *mut SLIST_ENTRY {
-    #[cfg(windows)]
-    {
-        #[link(name = "windows")]
-        extern "system" {
-            fn RtlFirstEntrySList(listhead: *const SLIST_HEADER) -> *mut SLIST_ENTRY;
-        }
-        ::core::mem::transmute(RtlFirstEntrySList(::core::mem::transmute(listhead)))
+    #[cfg_attr(windows, link(name = "windows"))]
+    extern "system" {
+        fn RtlFirstEntrySList(listhead: *const SLIST_HEADER) -> *mut SLIST_ENTRY;
     }
-    #[cfg(not(windows))]
-    unimplemented!("Unsupported target OS");
+    RtlFirstEntrySList(::core::mem::transmute(listhead))
 }
 #[doc = "*Required features: `\"Win32_System_Kernel\"`*"]
 #[inline]
 pub unsafe fn RtlInitializeSListHead(listhead: *mut SLIST_HEADER) {
-    #[cfg(windows)]
-    {
-        #[link(name = "windows")]
-        extern "system" {
-            fn RtlInitializeSListHead(listhead: *mut SLIST_HEADER);
-        }
-        RtlInitializeSListHead(::core::mem::transmute(listhead))
+    #[cfg_attr(windows, link(name = "windows"))]
+    extern "system" {
+        fn RtlInitializeSListHead(listhead: *mut SLIST_HEADER);
     }
-    #[cfg(not(windows))]
-    unimplemented!("Unsupported target OS");
+    RtlInitializeSListHead(::core::mem::transmute(listhead))
 }
 #[doc = "*Required features: `\"Win32_System_Kernel\"`*"]
 #[inline]
 pub unsafe fn RtlInterlockedFlushSList(listhead: *mut SLIST_HEADER) -> *mut SLIST_ENTRY {
-    #[cfg(windows)]
-    {
-        #[link(name = "windows")]
-        extern "system" {
-            fn RtlInterlockedFlushSList(listhead: *mut SLIST_HEADER) -> *mut SLIST_ENTRY;
-        }
-        ::core::mem::transmute(RtlInterlockedFlushSList(::core::mem::transmute(listhead)))
+    #[cfg_attr(windows, link(name = "windows"))]
+    extern "system" {
+        fn RtlInterlockedFlushSList(listhead: *mut SLIST_HEADER) -> *mut SLIST_ENTRY;
     }
-    #[cfg(not(windows))]
-    unimplemented!("Unsupported target OS");
+    RtlInterlockedFlushSList(::core::mem::transmute(listhead))
 }
 #[doc = "*Required features: `\"Win32_System_Kernel\"`*"]
 #[inline]
 pub unsafe fn RtlInterlockedPopEntrySList(listhead: *mut SLIST_HEADER) -> *mut SLIST_ENTRY {
-    #[cfg(windows)]
-    {
-        #[link(name = "windows")]
-        extern "system" {
-            fn RtlInterlockedPopEntrySList(listhead: *mut SLIST_HEADER) -> *mut SLIST_ENTRY;
-        }
-        ::core::mem::transmute(RtlInterlockedPopEntrySList(::core::mem::transmute(listhead)))
+    #[cfg_attr(windows, link(name = "windows"))]
+    extern "system" {
+        fn RtlInterlockedPopEntrySList(listhead: *mut SLIST_HEADER) -> *mut SLIST_ENTRY;
     }
-    #[cfg(not(windows))]
-    unimplemented!("Unsupported target OS");
+    RtlInterlockedPopEntrySList(::core::mem::transmute(listhead))
 }
 #[doc = "*Required features: `\"Win32_System_Kernel\"`*"]
 #[inline]
 pub unsafe fn RtlInterlockedPushEntrySList(listhead: *mut SLIST_HEADER, listentry: *mut SLIST_ENTRY) -> *mut SLIST_ENTRY {
-    #[cfg(windows)]
-    {
-        #[link(name = "windows")]
-        extern "system" {
-            fn RtlInterlockedPushEntrySList(listhead: *mut SLIST_HEADER, listentry: *mut SLIST_ENTRY) -> *mut SLIST_ENTRY;
-        }
-        ::core::mem::transmute(RtlInterlockedPushEntrySList(::core::mem::transmute(listhead), ::core::mem::transmute(listentry)))
+    #[cfg_attr(windows, link(name = "windows"))]
+    extern "system" {
+        fn RtlInterlockedPushEntrySList(listhead: *mut SLIST_HEADER, listentry: *mut SLIST_ENTRY) -> *mut SLIST_ENTRY;
     }
-    #[cfg(not(windows))]
-    unimplemented!("Unsupported target OS");
+    RtlInterlockedPushEntrySList(::core::mem::transmute(listhead), ::core::mem::transmute(listentry))
 }
 #[doc = "*Required features: `\"Win32_System_Kernel\"`*"]
 #[inline]
 pub unsafe fn RtlInterlockedPushListSListEx(listhead: *mut SLIST_HEADER, list: *mut SLIST_ENTRY, listend: *mut SLIST_ENTRY, count: u32) -> *mut SLIST_ENTRY {
-    #[cfg(windows)]
-    {
-        #[link(name = "windows")]
-        extern "system" {
-            fn RtlInterlockedPushListSListEx(listhead: *mut SLIST_HEADER, list: *mut SLIST_ENTRY, listend: *mut SLIST_ENTRY, count: u32) -> *mut SLIST_ENTRY;
-        }
-        ::core::mem::transmute(RtlInterlockedPushListSListEx(::core::mem::transmute(listhead), ::core::mem::transmute(list), ::core::mem::transmute(listend), ::core::mem::transmute(count)))
+    #[cfg_attr(windows, link(name = "windows"))]
+    extern "system" {
+        fn RtlInterlockedPushListSListEx(listhead: *mut SLIST_HEADER, list: *mut SLIST_ENTRY, listend: *mut SLIST_ENTRY, count: u32) -> *mut SLIST_ENTRY;
     }
-    #[cfg(not(windows))]
-    unimplemented!("Unsupported target OS");
+    RtlInterlockedPushListSListEx(::core::mem::transmute(listhead), ::core::mem::transmute(list), ::core::mem::transmute(listend), count)
 }
 #[doc = "*Required features: `\"Win32_System_Kernel\"`*"]
 #[inline]
 pub unsafe fn RtlQueryDepthSList(listhead: *const SLIST_HEADER) -> u16 {
-    #[cfg(windows)]
-    {
-        #[link(name = "windows")]
-        extern "system" {
-            fn RtlQueryDepthSList(listhead: *const SLIST_HEADER) -> u16;
-        }
-        ::core::mem::transmute(RtlQueryDepthSList(::core::mem::transmute(listhead)))
+    #[cfg_attr(windows, link(name = "windows"))]
+    extern "system" {
+        fn RtlQueryDepthSList(listhead: *const SLIST_HEADER) -> u16;
     }
-    #[cfg(not(windows))]
-    unimplemented!("Unsupported target OS");
+    RtlQueryDepthSList(::core::mem::transmute(listhead))
 }
 #[repr(C)]
 #[doc = "*Required features: `\"Win32_System_Kernel\"`*"]
@@ -1350,7 +1315,7 @@ impl ::core::default::Default for STRING64 {
 }
 #[doc = "*Required features: `\"Win32_System_Kernel\"`*"]
 #[repr(transparent)]
-#[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
+#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
 pub struct SUITE_TYPE(pub i32);
 #[doc = "*Required features: `\"Win32_System_Kernel\"`*"]
 pub const SmallBusiness: SUITE_TYPE = SUITE_TYPE(0i32);
@@ -1411,7 +1376,7 @@ impl ::core::fmt::Debug for SUITE_TYPE {
 }
 #[doc = "*Required features: `\"Win32_System_Kernel\"`*"]
 #[repr(transparent)]
-#[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
+#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
 pub struct TIMER_TYPE(pub i32);
 #[doc = "*Required features: `\"Win32_System_Kernel\"`*"]
 pub const NotificationTimer: TIMER_TYPE = TIMER_TYPE(0i32);
@@ -1438,7 +1403,7 @@ impl ::core::fmt::Debug for TIMER_TYPE {
 }
 #[doc = "*Required features: `\"Win32_System_Kernel\"`*"]
 #[repr(transparent)]
-#[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
+#[derive(::core::cmp::PartialEq, ::core::cmp::Eq)]
 pub struct WAIT_TYPE(pub i32);
 #[doc = "*Required features: `\"Win32_System_Kernel\"`*"]
 pub const WaitAll: WAIT_TYPE = WAIT_TYPE(0i32);
