@@ -9,11 +9,9 @@ pub struct AgileReference<T>(IAgileReference, PhantomData<T>);
 
 impl<T: Interface> AgileReference<T> {
     /// Creates an agile reference to the object.
-    pub fn new<'a>(object: &'a T) -> Result<Self>
-    where
-        &'a T: IntoParam<'a, IUnknown>,
-    {
-        unsafe { RoGetAgileReference(AGILEREFERENCE_DEFAULT, &T::IID, object).map(|reference| Self(reference, Default::default())) }
+    pub fn new(object: &T) -> Result<Self> {
+        let unknown: &IUnknown = unsafe { std::mem::transmute(object) };
+        unsafe { RoGetAgileReference(AGILEREFERENCE_DEFAULT, &T::IID, unknown).map(|reference| Self(reference, Default::default())) }
     }
 
     /// Retrieves a proxy to the target of the `AgileReference` object that may safely be used within any thread context in which get is called.
