@@ -16,7 +16,7 @@ impl Error {
     /// point of failure.
     pub fn new(code: HRESULT, message: HSTRING) -> Self {
         unsafe {
-            if let Ok(function) = delay_load(b"combase.dll\0", b"RoOriginateError\0") {
+            if let Ok(function) = delay_load(s!("combase.dll"), s!("RoOriginateError")) {
                 let function: RoOriginateError = core::mem::transmute(function);
                 function(code, core::mem::transmute_copy(&message));
             }
@@ -54,23 +54,12 @@ impl Error {
 
             if self.code == code {
                 let message = if !message.is_empty() { message } else { fallback };
-                return HSTRING::from_wide(message.as_wide());
+                return HSTRING::from_wide(wide_trim_end(message.as_wide()));
             }
         }
 
         self.code.message()
     }
-
-    /// Returns the win32 error code if the underlying HRESULT's facility is win32
-    #[cfg(feature = "Win32_Foundation")]
-    pub fn win32_error(&self) -> Option<crate::Win32::Foundation::WIN32_ERROR> {
-        let hresult = self.code.0 as u32;
-        if ((hresult >> 16) & 0x7FF) == 7 {
-            Some(crate::Win32::Foundation::WIN32_ERROR(hresult & 0xFFFF))
-        } else {
-            None
-        }
-    }
 }
 
 impl core::convert::From<Error> for HRESULT {
@@ -79,7 +68,7 @@ impl core::convert::From<Error> for HRESULT {
         let info = error.info.and_then(|info| info.cast().ok());
 
         unsafe {
-            let _ = SetErrorInfo(0, info);
+            let _ = SetErrorInfo(0, info.as_ref());
         }
 
         code
@@ -88,7 +77,17 @@ impl core::convert::From<Error> for HRESULT {
 
 impl core::convert::From<Error> for std::io::Error {
     fn from(from: Error) -> Self {
-        Self::from_raw_os_error((from.code.0 & 0xFFFF) as _)
+        Self::from_raw_os_error(from.code.0)
+    }
+}
+
+// Unfortunately this is needed to make types line up. The Rust type system does
+// not know the `Infallible` can never be constructed. This code needs to be here
+// to satesify the type checker but it will never be run. Once `!` is stabilizied
+// this can be removed.
+impl core::convert::From<core::convert::Infallible> for Error {
+    fn from(from: core::convert::Infallible) -> Self {
+        unreachable!()
     }
 }
 
