@@ -3,7 +3,7 @@
 use super::*;
 use bindings::*;
 
-/// A globally unique identifier [(GUID)](https://docs.microsoft.com/en-us/windows/win32/api/guiddef/ns-guiddef-guid)
+/// A globally unique identifier ([GUID](https://docs.microsoft.com/en-us/windows/win32/api/guiddef/ns-guiddef-guid))
 /// used to identify COM and WinRT interfaces.
 #[repr(C)]
 #[derive(Clone, Copy, Default, PartialEq, Eq, Hash)]
@@ -35,6 +35,11 @@ impl GUID {
         Self { data1: (uuid >> 96) as u32, data2: (uuid >> 80 & 0xffff) as u16, data3: (uuid >> 64 & 0xffff) as u16, data4: (uuid as u64).to_be_bytes() }
     }
 
+    /// Converts a `GUID` to a `u128` value.
+    pub const fn to_u128(&self) -> u128 {
+        ((self.data1 as u128) << 96) + ((self.data2 as u128) << 80) + ((self.data3 as u128) << 64) + u64::from_be_bytes(self.data4) as u128
+    }
+
     /// Creates a `GUID` for a "generic" WinRT type.
     pub const fn from_signature(signature: ConstBuffer) -> Self {
         let data = ConstBuffer::from_slice(&[0x11, 0xf4, 0x7a, 0xd5, 0x7b, 0x73, 0x42, 0xc0, 0xab, 0xae, 0x87, 0x8b, 0x1e, 0x16, 0xad, 0xee]);
@@ -59,10 +64,10 @@ unsafe impl Abi for GUID {
 
 unsafe impl RuntimeType for GUID {
     const SIGNATURE: ConstBuffer = ConstBuffer::from_slice(b"g16");
-}
-
-impl ::windows::core::DefaultType for GUID {
     type DefaultType = Self;
+    fn from_default(from: &Self::DefaultType) -> Result<Self> {
+        Ok(*from)
+    }
 }
 
 impl core::fmt::Debug for GUID {
@@ -97,6 +102,18 @@ impl core::convert::From<&str> for GUID {
     }
 }
 
+impl core::convert::From<u128> for GUID {
+    fn from(value: u128) -> Self {
+        Self::from_u128(value)
+    }
+}
+
+impl core::convert::From<GUID> for u128 {
+    fn from(value: GUID) -> Self {
+        value.to_u128()
+    }
+}
+
 trait HexReader {
     fn next_u8(&mut self) -> u8;
     fn next_u16(&mut self) -> u16;
