@@ -3,7 +3,7 @@ use bindings::*;
 
 /// An error code value returned by most COM functions.
 #[repr(transparent)]
-#[derive(Copy, Clone, Default, Debug, Eq, PartialEq)]
+#[derive(Copy, Clone, Default, Eq, PartialEq)]
 #[must_use]
 #[allow(non_camel_case_types)]
 pub struct HRESULT(pub i32);
@@ -33,11 +33,11 @@ impl HRESULT {
 
     /// Converts the [`HRESULT`] to [`Result<()>`][Result<_>].
     #[inline]
-    pub fn ok(self) -> Result<()> {
+    pub const fn ok(self) -> Result<()> {
         if self.is_ok() {
             Ok(())
         } else {
-            Err(self.into())
+            Err(Error { code: self, info: None })
         }
     }
 
@@ -66,11 +66,16 @@ impl HRESULT {
         Ok(op())
     }
 
-    /// # Safety
     /// If the [`Result`] is [`Ok`] converts the `T::Abi` into `T`.
-    pub unsafe fn from_abi<T: Abi>(self, abi: T::Abi) -> Result<T> {
+    ///
+    /// # Safety
+    ///
+    /// Safe to call if
+    /// * `abi` is initialized if `self` is `Ok`
+    /// * `abi` can be safely transmuted to `T`
+    pub unsafe fn from_abi<T: Abi>(self, abi: core::mem::MaybeUninit<T::Abi>) -> Result<T> {
         if self.is_ok() {
-            T::from_abi(abi)
+            T::from_abi(abi.assume_init())
         } else {
             Err(Error::from(self))
         }
@@ -83,7 +88,7 @@ impl HRESULT {
         unsafe {
             let size = FormatMessageW(FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM | FORMAT_MESSAGE_IGNORE_INSERTS, core::ptr::null(), self.0 as _, 0, PWSTR(core::mem::transmute(&mut message.0)), 0, core::ptr::null_mut());
 
-            HSTRING::from_wide(core::slice::from_raw_parts(message.0 as *const u16, size as usize))
+            HSTRING::from_wide(wide_trim_end(core::slice::from_raw_parts(message.0 as *const u16, size as usize)))
         }
     }
 }
@@ -110,6 +115,12 @@ impl<T> core::convert::From<Result<T>> for HRESULT {
     }
 }
 
+impl core::fmt::Debug for HRESULT {
+    fn fmt(&self, f: &mut core::fmt::Formatter<'_>) -> core::fmt::Result {
+        f.write_fmt(format_args!("HRESULT(0x{:08X})", self.0))
+    }
+}
+
 struct HeapString(*mut u16);
 
 impl Drop for HeapString {
