@@ -1,7 +1,9 @@
 mod abi;
 mod agile_reference;
 mod array;
+mod as_impl;
 pub(crate) mod bindings;
+mod borrowed;
 mod compose;
 mod delay_load;
 mod error;
@@ -11,20 +13,14 @@ mod generic_factory;
 mod guid;
 mod heap;
 mod hresult;
-mod hstring;
 mod inspectable;
 mod interface;
-mod into_param;
 mod param;
-mod pcstr;
-mod pcwstr;
-mod pstr;
-mod pwstr;
 mod ref_count;
 mod runtime_name;
 mod runtime_type;
 mod sha1;
-mod to_impl;
+mod strings;
 mod unknown;
 mod waiter;
 mod weak;
@@ -35,6 +31,9 @@ pub use abi::*;
 pub use agile_reference::*;
 pub use array::*;
 #[doc(hidden)]
+pub use as_impl::*;
+pub use borrowed::*;
+#[doc(hidden)]
 pub use compose::*;
 pub(crate) use delay_load::*;
 pub use error::*;
@@ -46,17 +45,9 @@ pub use generic_factory::*;
 pub use guid::*;
 pub(crate) use heap::*;
 pub use hresult::*;
-pub use hstring::*;
 pub use inspectable::*;
 pub use interface::*;
-#[doc(hidden)]
-pub use into_param::*;
-#[doc(hidden)]
 pub use param::*;
-pub use pcstr::*;
-pub use pcwstr::*;
-pub use pstr::*;
-pub use pwstr::*;
 #[doc(hidden)]
 pub use ref_count::*;
 #[doc(hidden)]
@@ -65,8 +56,7 @@ pub use runtime_name::*;
 pub use runtime_type::*;
 #[doc(hidden)]
 pub use sha1::*;
-#[doc(hidden)]
-pub use to_impl::*;
+pub use strings::*;
 pub use unknown::*;
 #[doc(hidden)]
 pub use waiter::*;
@@ -80,10 +70,6 @@ pub type Result<T> = core::result::Result<T, Error>;
 #[doc(hidden)]
 pub use bindings::IAgileObject;
 
-// TODO: rather than hiding, consider just removing
-#[doc(hidden)]
-pub type RawPtr = *mut core::ffi::c_void;
-
 #[doc(hidden)]
 #[cfg(feature = "implement")]
 pub use windows_implement::implement;
@@ -117,3 +103,13 @@ pub fn as_mut_ptr_or_null<T>(value: &mut [T]) -> *mut T {
         value.as_mut_ptr()
     }
 }
+
+fn wide_trim_end(mut wide: &[u16]) -> &[u16] {
+    while let Some(last) = wide.last() {
+        match last {
+            32 | 9..=13 => wide = &wide[..wide.len() - 1],
+            _ => break,
+        }
+    }
+    wide
+}
