@@ -10,9 +10,9 @@ pub struct IUnknown(core::ptr::NonNull<core::ffi::c_void>);
 #[doc(hidden)]
 #[repr(C)]
 pub struct IUnknownVtbl {
-    pub QueryInterface: unsafe extern "system" fn(this: RawPtr, iid: &GUID, interface: *mut RawPtr) -> HRESULT,
-    pub AddRef: unsafe extern "system" fn(this: RawPtr) -> u32,
-    pub Release: unsafe extern "system" fn(this: RawPtr) -> u32,
+    pub QueryInterface: unsafe extern "system" fn(this: *mut core::ffi::c_void, iid: &GUID, interface: *mut *const core::ffi::c_void) -> HRESULT,
+    pub AddRef: unsafe extern "system" fn(this: *mut core::ffi::c_void) -> u32,
+    pub Release: unsafe extern "system" fn(this: *mut core::ffi::c_void) -> u32,
 }
 
 unsafe impl Interface for IUnknown {
@@ -59,26 +59,41 @@ impl core::fmt::Debug for IUnknown {
 
 #[doc(hidden)]
 pub trait IUnknownImpl {
-    fn get_impl(&mut self) -> RawPtr;
+    type Impl;
+    /// Get a reference to the backing implementation.
+    fn get_impl(&self) -> &Self::Impl;
 
-    fn QueryInterface(&mut self, iid: &GUID, interface: *mut RawPtr) -> HRESULT;
-    fn AddRef(&mut self) -> u32;
-    fn Release(&mut self) -> u32;
+    /// The classic `QueryInterface` method from COM.
+    ///
+    /// # Safety
+    ///
+    /// This function is safe to call as long as the interface pointer is non-null and valid for writes
+    /// of an interface pointer.
+    unsafe fn QueryInterface(&self, iid: &GUID, interface: *mut *const core::ffi::c_void) -> HRESULT;
+    /// Increments the reference count of the interface
+    fn AddRef(&self) -> u32;
+    /// Decrements the reference count causing the interface's memory to be freed when the count is 0
+    ///
+    /// # Safety
+    ///
+    /// This function should only be called when the interfacer pointer is no longer used as calling `Release`
+    /// on a non-aliased interface pointer and then using that interface pointer may result in use after free.
+    unsafe fn Release(&self) -> u32;
 }
 
 #[cfg(any(feature = "interface", feature = "implement"))]
 impl IUnknownVtbl {
     pub const fn new<T: IUnknownImpl, const OFFSET: isize>() -> Self {
-        unsafe extern "system" fn QueryInterface<T: IUnknownImpl, const OFFSET: isize>(this: RawPtr, iid: &GUID, interface: *mut RawPtr) -> HRESULT {
-            let this = (this as *mut ::windows::core::RawPtr).offset(OFFSET) as *mut T;
+        unsafe extern "system" fn QueryInterface<T: IUnknownImpl, const OFFSET: isize>(this: *mut core::ffi::c_void, iid: &GUID, interface: *mut *const core::ffi::c_void) -> HRESULT {
+            let this = (this as *mut *mut core::ffi::c_void).offset(OFFSET) as *mut T;
             (*this).QueryInterface(iid, interface)
         }
-        unsafe extern "system" fn AddRef<T: IUnknownImpl, const OFFSET: isize>(this: RawPtr) -> u32 {
-            let this = (this as *mut ::windows::core::RawPtr).offset(OFFSET) as *mut T;
+        unsafe extern "system" fn AddRef<T: IUnknownImpl, const OFFSET: isize>(this: *mut core::ffi::c_void) -> u32 {
+            let this = (this as *mut *mut core::ffi::c_void).offset(OFFSET) as *mut T;
             (*this).AddRef()
         }
-        unsafe extern "system" fn Release<T: IUnknownImpl, const OFFSET: isize>(this: RawPtr) -> u32 {
-            let this = (this as *mut ::windows::core::RawPtr).offset(OFFSET) as *mut T;
+        unsafe extern "system" fn Release<T: IUnknownImpl, const OFFSET: isize>(this: *mut core::ffi::c_void) -> u32 {
+            let this = (this as *mut *mut core::ffi::c_void).offset(OFFSET) as *mut T;
             (*this).Release()
         }
         Self { QueryInterface: QueryInterface::<T, OFFSET>, AddRef: AddRef::<T, OFFSET>, Release: Release::<T, OFFSET> }
