@@ -32,7 +32,7 @@ impl WeakRefCount {
     }
 
     /// # Safety
-    pub unsafe fn query(&self, iid: &::windows::core::GUID, object: RawPtr) -> RawPtr {
+    pub unsafe fn query(&self, iid: &::windows::core::GUID, object: *mut core::ffi::c_void) -> *mut core::ffi::c_void {
         if iid != &IWeakReferenceSource::IID {
             return core::ptr::null_mut();
         }
@@ -44,13 +44,13 @@ impl WeakRefCount {
         }
 
         let tear_off = TearOff::new(object, count_or_pointer as _);
-        let tear_off_ptr: RawPtr = core::mem::transmute_copy(&tear_off);
+        let tear_off_ptr: *mut core::ffi::c_void = core::mem::transmute_copy(&tear_off);
         let encoding: usize = ((tear_off_ptr as usize) >> 1) | (1 << (core::mem::size_of::<usize>() * 8 - 1));
 
         loop {
             match self.0.compare_exchange_weak(count_or_pointer, encoding as _, Ordering::AcqRel, Ordering::Relaxed) {
                 Ok(_) => {
-                    let result: RawPtr = core::mem::transmute(tear_off);
+                    let result: *mut core::ffi::c_void = core::mem::transmute(tear_off);
                     TearOff::from_strong_ptr(result).strong_count.add_ref();
                     return result;
                 }
@@ -74,14 +74,14 @@ fn is_weak_ref(value: isize) -> bool {
 struct TearOff {
     strong_vtable: *const IWeakReferenceSource_Vtbl,
     weak_vtable: *const IWeakReference_Vtbl,
-    object: RawPtr,
+    object: *mut core::ffi::c_void,
     strong_count: RefCount,
     weak_count: RefCount,
 }
 
 impl TearOff {
     #[allow(clippy::new_ret_no_self)]
-    unsafe fn new(object: RawPtr, strong_count: u32) -> IWeakReferenceSource {
+    unsafe fn new(object: *mut core::ffi::c_void, strong_count: u32) -> IWeakReferenceSource {
         core::mem::transmute(windows::core::alloc::boxed::Box::new(TearOff {
             strong_vtable: &Self::STRONG_VTABLE,
             weak_vtable: &Self::WEAK_VTABLE,
@@ -91,7 +91,7 @@ impl TearOff {
         }))
     }
 
-    unsafe fn from_encoding(encoding: isize) -> RawPtr {
+    unsafe fn from_encoding(encoding: isize) -> *mut core::ffi::c_void {
         let tear_off = TearOff::decode(encoding);
         tear_off.strong_count.add_ref();
         core::mem::transmute(tear_off)
@@ -107,23 +107,23 @@ impl TearOff {
         Resolve: Self::WeakUpgrade,
     };
 
-    unsafe fn from_strong_ptr<'a>(this: RawPtr) -> &'a mut Self {
-        &mut *(this as *mut RawPtr as *mut Self)
+    unsafe fn from_strong_ptr<'a>(this: *mut core::ffi::c_void) -> &'a mut Self {
+        &mut *(this as *mut *mut core::ffi::c_void as *mut Self)
     }
 
-    unsafe fn from_weak_ptr<'a>(this: RawPtr) -> &'a mut Self {
-        &mut *((this as *mut RawPtr).sub(1) as *mut Self)
+    unsafe fn from_weak_ptr<'a>(this: *mut core::ffi::c_void) -> &'a mut Self {
+        &mut *((this as *mut *mut core::ffi::c_void).sub(1) as *mut Self)
     }
 
     unsafe fn decode<'a>(value: isize) -> &'a mut Self {
         core::mem::transmute(value << 1)
     }
 
-    unsafe fn query_interface(&self, iid: &GUID, interface: *mut RawPtr) -> HRESULT {
+    unsafe fn query_interface(&self, iid: &GUID, interface: *mut *const core::ffi::c_void) -> HRESULT {
         ((*(*(self.object as *mut *mut _) as *mut IUnknownVtbl)).QueryInterface)(self.object, iid, interface)
     }
 
-    unsafe extern "system" fn StrongQueryInterface(ptr: RawPtr, iid: &GUID, interface: *mut RawPtr) -> HRESULT {
+    unsafe extern "system" fn StrongQueryInterface(ptr: *mut core::ffi::c_void, iid: &GUID, interface: *mut *const core::ffi::c_void) -> HRESULT {
         let this = Self::from_strong_ptr(ptr);
 
         // Only directly respond to queries for the the tear-off's strong interface. This is
@@ -139,7 +139,7 @@ impl TearOff {
         this.query_interface(iid, interface)
     }
 
-    unsafe extern "system" fn WeakQueryInterface(ptr: RawPtr, iid: &GUID, interface: *mut RawPtr) -> HRESULT {
+    unsafe extern "system" fn WeakQueryInterface(ptr: *mut core::ffi::c_void, iid: &GUID, interface: *mut *const core::ffi::c_void) -> HRESULT {
         let this = Self::from_weak_ptr(ptr);
 
         // While the weak vtable is packed into the same allocation as the strong vtable and
@@ -158,21 +158,21 @@ impl TearOff {
         }
     }
 
-    unsafe extern "system" fn StrongAddRef(ptr: ::windows::core::RawPtr) -> u32 {
+    unsafe extern "system" fn StrongAddRef(ptr: *mut core::ffi::c_void) -> u32 {
         let this = Self::from_strong_ptr(ptr);
 
         // Implement `AddRef` directly as we own the strong reference.
         this.strong_count.add_ref()
     }
 
-    unsafe extern "system" fn WeakAddRef(ptr: ::windows::core::RawPtr) -> u32 {
+    unsafe extern "system" fn WeakAddRef(ptr: *mut core::ffi::c_void) -> u32 {
         let this = Self::from_weak_ptr(ptr);
 
         // Implement `AddRef` directly as we own the weak reference.
         this.weak_count.add_ref()
     }
 
-    unsafe extern "system" fn StrongRelease(ptr: ::windows::core::RawPtr) -> u32 {
+    unsafe extern "system" fn StrongRelease(ptr: *mut core::ffi::c_void) -> u32 {
         let this = Self::from_strong_ptr(ptr);
 
         // Forward strong `Release` to the object so that it can destroy itself. It will then
@@ -180,7 +180,7 @@ impl TearOff {
         ((*(*(this.object as *mut *mut _) as *mut IUnknownVtbl)).Release)((*this).object)
     }
 
-    unsafe extern "system" fn WeakRelease(ptr: ::windows::core::RawPtr) -> u32 {
+    unsafe extern "system" fn WeakRelease(ptr: *mut core::ffi::c_void) -> u32 {
         let this = Self::from_weak_ptr(ptr);
 
         // Implement `Release` directly as we own the weak reference.
@@ -189,13 +189,13 @@ impl TearOff {
         // If there are no remaining references, it means that the object has already been
         // destroyed. Go ahead and destroy the tear-off.
         if remaining == 0 {
-            windows::core::alloc::boxed::Box::from_raw(this);
+            let _ = windows::core::alloc::boxed::Box::from_raw(this);
         }
 
         remaining
     }
 
-    unsafe extern "system" fn StrongDowngrade(ptr: RawPtr, interface: *mut RawPtr) -> HRESULT {
+    unsafe extern "system" fn StrongDowngrade(ptr: *mut core::ffi::c_void, interface: *mut *mut core::ffi::c_void) -> HRESULT {
         let this = Self::from_strong_ptr(ptr);
 
         // The strong vtable hands out a reference to the weak vtable. This is always safe and
@@ -206,7 +206,7 @@ impl TearOff {
         HRESULT(0)
     }
 
-    unsafe extern "system" fn WeakUpgrade(ptr: RawPtr, iid: *const GUID, interface: *mut RawPtr) -> HRESULT {
+    unsafe extern "system" fn WeakUpgrade(ptr: *mut core::ffi::c_void, iid: *const GUID, interface: *mut *mut core::ffi::c_void) -> HRESULT {
         let this = Self::from_weak_ptr(ptr);
 
         this.strong_count
@@ -218,7 +218,7 @@ impl TearOff {
             })
             .map(|_| {
                 // Let the object respond to the upgrade query.
-                let result = this.query_interface(&*iid, interface);
+                let result = this.query_interface(&*iid, interface as *mut _);
                 // Decrement the temporary reference account used to stabilize the object.
                 this.strong_count.0.fetch_sub(1, Ordering::Relaxed);
                 // Return the result of the query.
